@@ -44,9 +44,7 @@
 #include <errno.h>
 #include <ctype.h>
 
-#ifdef HAVE_LOCALE_H
 #include <locale.h>
-#endif
 
 #ifdef HAVE_SYS_TIME_H
 # include <sys/time.h>
@@ -517,7 +515,7 @@ int mutt_is_malformed_multipart_pgp_encrypted (BODY *b)
 }
 
 
-int mutt_is_application_pgp (BODY *m)
+int mutt_is_application_pgp (const BODY *m)
 {
   int t = 0;
   char *p;
@@ -712,7 +710,7 @@ int crypt_write_signed(BODY *a, STATE *s, const char *tempfile)
     return -1;
   }
 
-  fseeko (s->fpin, a->hdr_offset, 0);
+  fseeko (s->fpin, a->hdr_offset, SEEK_SET);
   bytes = a->length + a->offset - a->hdr_offset;
   hadcr = 0;
   while (bytes > 0)
@@ -943,6 +941,7 @@ int crypt_get_keys (HEADER *msg, char **keylist, int oppenc_mode)
   if (fqdn)
     rfc822_qualify (adrlist, fqdn);
   adrlist = mutt_remove_duplicates (adrlist);
+  adrlist = mutt_remove_adrlist_group_delimiters (adrlist);
 
   if (oppenc_mode || (msg->security & ENCRYPT))
   {
