@@ -20,7 +20,7 @@ char *mutt_choose_charset (const char *fromcode, const char *charsets,
                            char *u, size_t ulen, char **d, size_t *dlen);
 int convert_nonmime_string (char **);
 
-void _rfc2047_encode_string (char **, int, int);
+int _rfc2047_encode_string (char **, int, int);
 void rfc2047_encode_adrlist (ADDRESS *, const char *);
 void rfc2047_encode_envelope (ENVELOPE *);
 
