@@ -162,7 +162,7 @@ static int ciss_parse_userhost (ciss_url_t *ciss, char *src)
   {
     int t;
     *p++ = '\0';
-    if (mutt_atoi (p, &t) < 0 || t < 0 || t > 0xffff)
+    if (mutt_atoi (p, &t, MUTT_ATOI_ALLOW_EMPTY) < 0 || t < 0 || t > 0xffff)
       return -1;
     ciss->port = (unsigned short)t;
   }
@@ -275,6 +275,21 @@ int url_ciss_tobuffer (ciss_url_t* ciss, BUFFER* dest, int flags)
   return 0;
 }
 
+/* This is similar to mutt_matches_ignore(), except that it
+ * doesn't allow prefix matches.
+ */
+static int url_mailto_header_allowed (const char *header)
+{
+  LIST *t = MailtoAllow;
+
+  for (; t; t = t->next)
+  {
+    if (!ascii_strcasecmp (header, t->data) || *t->data == '*')
+      return 1;
+  }
+  return 0;
+}
+
 int url_parse_mailto (ENVELOPE *e, char **body, const char *src)
 {
   char *t, *p;
@@ -315,6 +330,8 @@ int url_parse_mailto (ENVELOPE *e, char **body, const char *src)
     if (url_pct_decode (value) < 0)
       goto out;
 
+    mutt_filter_commandline_header_tag (tag);
+
     /* Determine if this header field is on the allowed list.  Since Mutt
      * interprets some header fields specially (such as
      * "Attach: ~/.gnupg/secring.gpg"), care must be taken to ensure that
@@ -326,7 +343,7 @@ int url_parse_mailto (ENVELOPE *e, char **body, const char *src)
      * choose to create a message with only a subset of the headers given in
      * the URL.
      */
-    if (mutt_matches_ignore(tag, MailtoAllow))
+    if (url_mailto_header_allowed (tag))
     {
       if (!ascii_strcasecmp (tag, "body"))
       {
@@ -338,6 +355,7 @@ int url_parse_mailto (ENVELOPE *e, char **body, const char *src)
       else if (!ascii_strcasecmp (tag, "in-reply-to"))
       {
         mutt_free_list (&e->in_reply_to);
+        mutt_filter_commandline_header_value (value);
         e->in_reply_to = mutt_parse_references (value, 1);
       }
       else
@@ -345,6 +363,7 @@ int url_parse_mailto (ENVELOPE *e, char **body, const char *src)
 	char *scratch;
 	size_t taglen = mutt_strlen (tag);
 
+        mutt_filter_commandline_header_value (value);
 	safe_asprintf (&scratch, "%s: %s", tag, value);
 	scratch[taglen] = 0; /* overwrite the colon as mutt_parse_rfc822_line expects */
 	value = skip_email_wsp(&scratch[taglen + 1]);
